---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ['type:bug', 'status:new']
assignees: ''
---

## Environment

- ggshield version:
- Operating system (Linux, macOS, Windows):
- Operating system version:
- Python version:

## Describe the bug

A clear and concise description of what the bug is.

Steps to reproduce:

1. Setup steps required to reproduce the issue
2. Run command `ggshield scan something`
3. …

Actual result:

<!--what currently happens-->

Expected result:

<!--what should happen instead -->

If applicable, add logs or screenshots to help explain your problem.
